#
# spec file for package boost-base
#
# Copyright (c) 2022-2023 ZhuningOS
#


%define ver 1.66.0
%define file_version 1_66_0
%define docs_version 1.56.0
%define short_version 1_56
%define lib_appendix 1_66_0
%bcond_with    build_docs
%bcond_without package_pdf
%bcond_without build_quickbook
%bcond_with    boost_devel
%define my_docdir %{_docdir}/boost-%{version}

%if "base" == "base"
%define build_base 1
%define name_suffix -base
%else
%define build_base 0
%define name_suffix %nil
%endif

# Build with OpenMPI
%if 0%{?suse_version} >= 1330
  # OpenMPI >= 2 is not available on ppc64be
  %ifarch ppc64
    %define mpi_implem openmpi
  %else
    %define mpi_implem openmpi2
  %endif
%else
  # Keep OpenMPI1 for older releases where OpenMPI2 is not available
  %define mpi_implem openmpi
%endif

%ifarch ia64 hppa
%bcond_with  build_mpi
%else
%bcond_without build_mpi
%endif

%bcond_without python3
%bcond_without python2

# Python NumPy library is only available on Leap 42.1 OpenSUSE onward
# and is not availble in SLE
%if 0%{?suse_version} >= 1330 || 0%{?is_opensuse}
%bcond_without python_numpy
%else
%bcond_with python_numpy
%endif

# context hasn't been ported to most architectures yet
%ifarch %ix86 x86_64 %arm aarch64 mips ppc ppc64 ppc64le
%bcond_without build_context
%else
%bcond_with build_context
%endif

# needs newer *default* GCC to compile runtime
%if %{with build_context} && 0%{?suse_version} > 1320
%bcond_without boost_fiber
%else
%bcond_with boost_fiber
%endif

Name:           boost%name_suffix
%define package_name boost_1_66
Version:        1.66.0
Release:        12.3.1
Summary:        Boost C++ Libraries
License:        BSL-1.0
Group:          Development/Libraries/C and C++
Url:            http://www.boost.org
Source0:        http://downloads.sourceforge.net/project/boost/boost/%{version}/boost_%{file_version}.tar.bz2
Source1:        boost-rpmlintrc
Source3:        http://downloads.sourceforge.net/project/boost/boost-docs/%{docs_version}/boost_%{short_version}_pdf.tar.bz2
Source4:        existing_extra_docs
#Source5:        NEWS
Source10:       exception.objdump
Source11:       __init__.py
Source100:      baselibs.conf
Source101:      symbol_diff.sh
Source102:      README.boost-devel
Patch1:         boost-thread.patch
Patch2:         boost-no_type_punning.patch
Patch3:         boost-no_segfault_in_Regex_filter.patch
Patch4:         boost-pool_check_overflow.patch
Patch5:         boost-strict_aliasing.patch
Patch6:         boost-use_std_xml_catalog.patch
Patch7:         boost-rpmoptflags-only.patch
Patch9:         boost-aarch64-flags.patch
Patch10:        boost-disable-pch-on-aarch64.patch
Patch13:        boost-visibility.patch
Patch14:        boost-1.57.0-python-libpython_dep.patch
Patch15:        boost-1.57.0-python-abi_letters.patch
Patch16:        boost-1.55.0-python-test-PyImport_AppendInittab.patch
Patch17:        python_mpi.patch
Patch18:        dynamic_linking.patch
Patch20:        python_library_name.patch
Patch21:        python_numpy_retfunc.patch
Patch22:        libreoffice_compat_backports.patch
Patch23:        variant.patch
BuildRequires:  fdupes
BuildRequires:  libbz2-devel
BuildRequires:  libexpat-devel
BuildRequires:  libicu-devel
BuildRequires:  zlib-devel
%if %{with boost_fiber}
BuildRequires:  gcc-c++ > 5
%else
BuildRequires:  gcc-c++
%endif
%if ! %build_base
BuildRequires:  dos2unix
%if %{with python2}
BuildRequires:  python2-devel
%if %{with python_numpy}
BuildRequires:  python2-numpy-devel
%endif # numpy2
%endif # python2
%if %{with python3}
BuildRequires:  python3-devel
%if %{with python_numpy}
BuildRequires:  python3-numpy-devel
%endif # numpy3
%endif # python3
%if %{with build_mpi}
BuildRequires:  %{mpi_implem}-devel
%endif
%if %{with build_docs}
BuildRequires:  docbook
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  libxslt-tools
BuildRequires:  texlive-latex
%endif
%endif # ! build_base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Boost provides free peer-reviewed portable C++ source libraries. The
emphasis is on libraries that work well with the C++ Standard Library.
One goal is to establish "existing practice" and provide reference
implementations so that the Boost libraries are suitable for eventual
standardization. Some of the libraries have already been proposed for
inclusion in the C++ Standards Committee's upcoming C++ Standard
Library Technical Report.

Although Boost was begun by members of the C++ Standards Committee
Library Working Group, membership has expanded to include nearly two
thousand members of the C++ community at large.

# %%if %%build_base
%package     -n libboost_headers%{lib_appendix}-devel
Summary:        Development headers for Boost
Group:          Development/Libraries/C and C++
Requires:       boost-license%{lib_appendix}
Requires:       libstdc++-devel
Provides:       libboost_headers-devel = %{version}
%if %{without boost_devel}
Provides:       boost-devel = %{version}
%endif
Conflicts:      otherproviders(libboost_headers-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_headers%{lib_appendix}-devel
A collection of header-only libraries for Boost.

%package     -n boost-license%{lib_appendix}
Summary:        Boost License
Group:          Development/Libraries/C and C++
Provides:       boost-license = %{version}-%{release}
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description -n boost-license%{lib_appendix}
This package contains the license boost is provided under.

%if %{with boost_devel}
%package -n     %{package_name}-devel
Summary:        Development package for Boost C++
Group:          Development/Libraries/C and C++
Requires:       libboost_atomic%{lib_appendix}-devel
Requires:       libboost_chrono%{lib_appendix}-devel
Requires:       libboost_container%{lib_appendix}-devel
%if %{with build_context}
Requires:       libboost_context%{lib_appendix}-devel
Requires:       libboost_coroutine%{lib_appendix}-devel
%endif
Requires:       libboost_date_time%{lib_appendix}-devel
%if %{with boost_fiber}
Requires:       libboost_fiber%{lib_appendix}-devel
%endif
Requires:       libboost_filesystem%{lib_appendix}-devel
Requires:       libboost_graph%{lib_appendix}-devel
Requires:       libboost_iostreams%{lib_appendix}-devel
Requires:       libboost_locale%{lib_appendix}-devel
Requires:       libboost_log%{lib_appendix}-devel
Requires:       libboost_math%{lib_appendix}-devel
%if %{with build_mpi}
Requires:       libboost_graph_parallel%{lib_appendix}-devel
Requires:       libboost_mpi%{lib_appendix}-devel
%endif
Requires:       libboost_program_options%{lib_appendix}-devel
%if %{with python2}
Requires:       libboost_python-py2_7-%{lib_appendix}-devel
%endif
%if %{with python3}
Requires:       libboost_python-py3-%{lib_appendix}-devel
%endif
Requires:       libboost_random%{lib_appendix}-devel
Requires:       libboost_regex%{lib_appendix}-devel
Requires:       libboost_serialization%{lib_appendix}-devel
Requires:       libboost_signals%{lib_appendix}-devel
Requires:       libboost_system%{lib_appendix}-devel
Requires:       libboost_test%{lib_appendix}-devel
Requires:       libboost_thread%{lib_appendix}-devel
Requires:       libboost_timer%{lib_appendix}-devel
Requires:       libboost_type_erasure%{lib_appendix}-devel
Requires:       libboost_wave%{lib_appendix}-devel
Requires:       libstdc++-devel
Provides:       boost-devel = %version
Conflicts:      otherproviders(boost-devel)

%description -n %{package_name}-devel
This package contains all that is needed to develop/compile
applications that use the Boost C++ libraries. For documentation see
the documentation packages (html, man or pdf).
%endif # with boost_devel

%package     -n %{package_name}-jam
Summary:        A Boost Make Replacement
Group:          Development/Tools/Building
Provides:       boost-jam
Conflicts:      otherproviders(boost-jam)

%description -n %{package_name}-jam
Boost Jam is a build tool based on FTJam, which in turn is based on
Perforce Jam. It contains significant improvements made to facilitate
its use in the Boost Build System.

%package      -n %{package_name}-doc-html
Summary:        HTML documentation for the Boost C++ Libraries
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description  -n %{package_name}-doc-html
This package contains the documentation of the boost dynamic libraries
in HTML format.

%if %{with build_docs}
%package        doc-man
Summary:        Man documentation for the Boost C++ Libraries
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description    doc-man
This package contains the documentation of the boost dynamic libraries
as man pages.
%endif

%if %{with package_pdf}
%package      -n %{package_name}-doc-pdf
Summary:        PDF documentation for the Boost C++ Libraries
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description  -n %{package_name}-doc-pdf
This package contains the documentation of the boost dynamic libraries
in PDF format.
%endif

%package     -n libboost_atomic%{lib_appendix}
Summary:        Boost.Atomic runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_atomic%{lib_appendix}
Run-Time support for Boost.Atomic, a library that provides atomic data types
and operations on these data types, as well as memory ordering constraints
required for coordinating multiple threads through atomic variables.

%package     -n libboost_atomic%{lib_appendix}-devel
Summary:        Development headers for Boost.Atomic
Group:          Development/Libraries/C and C++
Requires:       libboost_atomic%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_atomic-devel = %{version}
Conflicts:      otherproviders(libboost_atomic-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_atomic%{lib_appendix}-devel
Development support for Boost.Atomic, a library that provides atomic
data types and operations on these data types, as well as memory
ordering constraints required for coordinating multiple threads through
atomic variables.

%package     -n libboost_container%{lib_appendix}
Summary:        Boost.Container runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_container%{lib_appendix}
This package contains the Boost.Container runtime library.

%package     -n libboost_container%{lib_appendix}-devel
Summary:        Development headers for Boost.Container
Group:          Development/Libraries/C and C++
Requires:       libboost_container%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_container-devel = %{version}
Conflicts:      otherproviders(libboost_container-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_container%{lib_appendix}-devel
Development header files and libraries for Boost.Container.
Boost.Container library implements several well-known containers,
including STL containers. The aim of the library is to offers advanced
features not present in standard containers or to offer the latest
standard draft features for compilers that don't comply with the latest
C++ standard.

%package     -n libboost_context%{lib_appendix}
Summary:        Boost.Context runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_context%{lib_appendix}
Runtime support for Boost.Context, a library that providing cooperative
multitasking support.

%package     -n libboost_context%{lib_appendix}-devel
Summary:        Development headers for Boost.Context
Group:          Development/Libraries/C and C++
Requires:       libboost_context%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_context-devel = %{version}
Conflicts:      otherproviders(libboost_context-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_context%{lib_appendix}-devel
Development headers and libraries for Boost.Context, a library that
providing cooperative multitasking support.

%package     -n libboost_coroutine%{lib_appendix}
Summary:        Boost::Coroutine runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_coroutine%{lib_appendix}
This package contains the Boost Coroutine runtime library.

%package     -n libboost_coroutine%{lib_appendix}-devel
Summary:        Development headers for Boost.Coroutine
Group:          Development/Libraries/C and C++
Requires:       libboost_context%{lib_appendix}-devel = %{version}
Requires:       libboost_coroutine%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_coroutine-devel = %{version}
Conflicts:      otherproviders(libboost_coroutine-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_coroutine%{lib_appendix}-devel
This package provides headers for Boost.Coroutine libraries.
Boost.Coroutine2 provides templates for generalized subroutines which
allow suspending and resuming execution at certain locations.

%package     -n libboost_date_time%{lib_appendix}
Summary:        Boost.DateTime runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_date_time%{lib_appendix}
This package contains the Boost Date.DateTime runtime libraries.

%package     -n libboost_date_time%{lib_appendix}-devel
Summary:        Development headers for Boost.DateTime library
Group:          Development/Libraries/C and C++
Requires:       libboost_date_time%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Recommends:     libboost_serialization%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_date_time-devel = %{version}
Conflicts:      otherproviders(libboost_date_time-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_date_time%{lib_appendix}-devel
This package contains development header files and libraries for
Boost.DateTime library.

%package     -n libboost_fiber%{lib_appendix}
Summary:        Boost.Fiber runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_fiber%{lib_appendix}
This package contains Boost.Fiber runtime library.

%package     -n libboost_fiber%{lib_appendix}-devel
Summary:        Development headers for Boost.Fiber library
Group:          Development/Libraries/C and C++
Requires:       libboost_context%{lib_appendix}-devel = %{version}
Requires:       libboost_fiber%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_fiber-devel = %{version}
Conflicts:      otherproviders(libboost_fiber-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_fiber%{lib_appendix}-devel
This package contains development header files and libraries for
Boost.Fiber library. Boost.Fiber is a cooperative multi-tasking
userland threading library.

%package     -n libboost_filesystem%{lib_appendix}
Summary:        Boost.Filesystem Runtime Libraries
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_filesystem%{lib_appendix}
This package contains the Boost.Filesystem library.

%package     -n libboost_filesystem%{lib_appendix}-devel
Summary:        Development headers for Boost.Filesystem library
Group:          Development/Libraries/C and C++
Requires:       libboost_filesystem%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_system%{lib_appendix}-devel = %{version}
Requires:       libstdc++-devel
Provides:       libboost_filesystem-devel = %{version}
Conflicts:      otherproviders(libboost_filesystem-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_filesystem%{lib_appendix}-devel
Development headers for Boost.Filesystem library, a library providing
facilities to manipulate files and directories, and the paths that
identify them.

%package     -n libboost_graph%{lib_appendix}
Summary:        Boost.Graph runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_graph%{lib_appendix}
This package contains the Boost.Graph runtime library.

%package     -n libboost_graph%{lib_appendix}-devel
Summary:        Development headers for Boost.Graph library
Group:          Development/Libraries/C and C++
Requires:       libboost_graph%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
## FIXME:!!!! need better list of requirements here
Requires:       libstdc++-devel
Provides:       libboost_graph-devel = %{version}
Conflicts:      otherproviders(libboost_graph-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_graph%{lib_appendix}-devel
Development headers for Boost.Graph library. The BGL algorithms consist
of a core set of algorithm patterns and a larger set of graph
algorithms. The core algorithm patterns are Breadth First Search, Depth
First Search, and Uniform Cost Search.


%package     -n libboost_iostreams%{lib_appendix}
Summary:        Boost.IOStreams Runtime Libraries
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_iostreams%{lib_appendix}
This package contains the Boost.IOStreams Runtime libraries.

%package     -n libboost_iostreams%{lib_appendix}-devel
Summary:        Development headers for Boost.IOStreans library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_iostreams%{lib_appendix} = %{version}
Provides:       libboost_iostreams-devel = %{version}
Conflicts:      otherproviders(libboost_iostreams-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_iostreams%{lib_appendix}-devel
Boost.IOStreams provides a framework for defining streams, stream
buffers and IO filters

%package     -n libboost_log%{lib_appendix}
Summary:        Boost.Log runtime Run-Time library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_log%{lib_appendix}
This package contains runtime library for Boost.Log.

%package     -n libboost_log%{lib_appendix}-devel
Summary:        Development headers for Boost.Log library
Group:          Development/Libraries/C and C++
Requires:       libboost_date_time%{lib_appendix}-devel = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_log%{lib_appendix} = %{version}
Requires:       libboost_system%{lib_appendix} = %{version}
Requires:       libboost_thread%{lib_appendix} = %{version}
Provides:       libboost_log-devel = %{version}
Conflicts:      otherproviders(libboost_log-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_log%{lib_appendix}-devel
Development headers for Boost.Log library which aims to make logging
significantly easier for the application developer. It provides a wide
range of out-of-the-box tools along with public interfaces for extending
the library.

%package     -n libboost_math%{lib_appendix}
Summary:        Boost.Math runtime libraries
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_math%{lib_appendix}
This package contains the Boost.Math Runtime libraries.

%package     -n libboost_math%{lib_appendix}-devel
Summary:        Development headers for Boost.Math libraries
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_math%{lib_appendix} = %{version}
Provides:       libboost_math-devel = %{version}
Conflicts:      otherproviders(libboost_math-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_math%{lib_appendix}-devel
Development headers for Boost.Math* boost libraries.

%if %{with build_mpi}
%package     -n libboost_mpi%{lib_appendix}
Summary:        Boost.MPI runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_mpi%{lib_appendix}
This package contains the Boost.MPI runtime library.

%package     -n libboost_mpi%{lib_appendix}-devel
Summary:        Development headers for Boost.MPI library
Group:          Development/Libraries/C and C++
Requires:       libboost_graph%{lib_appendix}-devel
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
%if %{with python2}
Requires:       libboost_python-py2_7-%{lib_appendix}-devel
%endif
%if %{with python3}
Requires:       libboost_python-py3-%{lib_appendix}-devel
%endif
Requires:       %{mpi_implem}-devel
Requires:       libboost_mpi%{lib_appendix} = %{version}
Requires:       libboost_serialization%{lib_appendix}-devel
Provides:       libboost_mpi-devel = %{version}
Conflicts:      otherproviders(libboost_mpi-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_mpi%{lib_appendix}-devel
Development headers for Boost.MPI boost library

%package     -n libboost_graph_parallel%{lib_appendix}
Summary:        Boost.Graph.Distributed runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_graph_parallel%{lib_appendix}
This package contains the Boost.Graph parallel runtime library

%package     -n libboost_graph_parallel%{lib_appendix}-devel
Summary:        Development headers for Boost.Graph parallel library
Group:          Development/Libraries/C and C++
Requires:       libboost_graph_parallel%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_mpi%{lib_appendix}-devel = %{version}
Provides:       libboost_graph_parallel-devel = %{version}
Conflicts:      otherproviders(libboost_graph_parallel-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_graph_parallel%{lib_appendix}-devel
Development headers for Boost.Graph parallel boost library.

%if %{with python2}
%package     -n libboost_mpi_python-py2_7-%{lib_appendix}
Summary:        Boost.MPI Python serialization library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_mpi_python-py2_7-%{lib_appendix}
This package contains the Boost.MPI Python 2.7 serialization library

%package     -n libboost_mpi_python-py2_7-%{lib_appendix}-devel
Summary:        Development library for Boost.MPI Python 2.7 serialization
Group:          Development/Libraries/C and C++
Requires:       libboost_mpi%{lib_appendix}-devel = %{version}
Requires:       libboost_mpi_python-py2_7-%{lib_appendix} = %{version}
Requires:       libboost_python-py2_7-%{lib_appendix} = %{version}
Provides:       libboost_mpi_python-devel = %{version}
Conflicts:      otherproviders(libboost_mpi_python-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_mpi_python-py2_7-%{lib_appendix}-devel
This package contains the Boost.MPI development library for Python 2.7
serialization interface.


%package     -n python2-boost_parallel_mpi%{lib_appendix}
Summary:        Python 2.7 bindings for Boost.Parallel.MPI library
Group:          Development/Languages/Python
Provides:       python-boost_parallel_mpi = %{version}
Provides:       python-boost_parallel_mpi%{lib_appendix} = %{version}
Conflicts:      otherproviders(python-boost_parallel_mpi)

%description -n python2-boost_parallel_mpi%{lib_appendix}
This package contains the Boost.Parallel.MPI bindings for Python 2.7

%endif # python2

%if %{with python3}

%package     -n libboost_mpi_python-py3-%{lib_appendix}
Summary:        Boost.MPI Python 3.x serialization library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_mpi_python-py3-%{lib_appendix}
This package contains the Boost.MPI Python 3.x serialization
inteface.

%package     -n libboost_mpi_python-py3-%{lib_appendix}-devel
Summary:        Development library for Boost.MPI Python 3.x serialization
Group:          Development/Libraries/C and C++
Requires:       libboost_mpi%{lib_appendix}-devel = %{version}
Requires:       libboost_mpi_python-py3-%{lib_appendix} = %{version}
Requires:       libboost_python-py3-%{lib_appendix} = %{version}
Provides:       libboost_mpi_python3-devel = %{version}
Conflicts:      otherproviders(libboost_mpi_python3-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_mpi_python-py3-%{lib_appendix}-devel
This package contains the Boost.MPI development library for Python 3.x
serialization interface

%package     -n python3-boost_parallel_mpi%{lib_appendix}
Summary:        Python 3.x bindings for Boost.Parallel.MPI library
Group:          Development/Languages/Python
Provides:       python3-boost_parallel_mpi = %{version}
Conflicts:      otherproviders(python3-boost_parallel_mpi)

%description -n python3-boost_parallel_mpi%{lib_appendix}
This package contains the Boost.Parallel.MPI bindings for Python 3.x

%endif  # python3
%endif  # mpi

%package    -n libboost_test%{lib_appendix}
Summary:        Boost.Test runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_test%{lib_appendix}
This package contains the BoosttTest runtime library.

%package     -n libboost_test%{lib_appendix}-devel
Summary:        Development headers for Boost.Test library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_test%{lib_appendix} = %{version}
Provides:       libboost_test-devel = %{version}
Conflicts:      otherproviders(libboost_test-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_test%{lib_appendix}-devel
Development headers for Boost.Test library. Boost.Test supports for
simple program testing, full unit testing, and for program execution
monitoring.

%package     -n libboost_program_options%{lib_appendix}
Summary:        Boost.ProgramOptions runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_program_options%{lib_appendix}
This package contains the Boost.ProgramOptions runtime library.

%package     -n libboost_program_options%{lib_appendix}-devel
Summary:        Development headers for Boost.ProgramOptions library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_program_options%{lib_appendix} = %{version}
Provides:       libboost_program_options-devel = %{version}
Conflicts:      otherproviders(libboost_program_options-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_program_options%{lib_appendix}-devel
This package contains development headers for Boost.ProgramOptions
library.

%if %{with python2}
%package     -n libboost_python-py2_7-%{lib_appendix}
Summary:        Boost.Python runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_python-py2_7-%{lib_appendix}
This package contains the Boost::Python runtime library for default
version of python.

%package     -n libboost_python-py2_7-%{lib_appendix}-devel
Summary:        Development headers for Boost.Python library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_python-py2_7-%{lib_appendix} = %{version}
Provides:       libboost_python-devel = %{version}
Conflicts:      otherproviders(libboost_python-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_python-py2_7-%{lib_appendix}-devel
Development headers for Boost::Python library for the default version of
python.

%if %{with python_numpy}
%package     -n libboost_numpy-py2_7-%{lib_appendix}
Summary:        Boost.Python.NumPy runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_numpy-py2_7-%{lib_appendix}
This package contains the Boost::Python::NumPy runtime library for default
version of python.

%package     -n libboost_numpy-py2_7-%{lib_appendix}-devel
Summary:        Development headers for Boost.Python.NumPy library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_numpy-py2_7-%{lib_appendix} = %{version}
Provides:       libboost_numpy-devel = %{version}
Conflicts:      otherproviders(libboost_numpy-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_numpy-py2_7-%{lib_appendix}-devel
Development headers for Boost::Python::NumPy library for the default version of
python.
%endif # with numpy
%endif # with python2

%if %{with python3}
%package     -n libboost_python-py3-%{lib_appendix}
Summary:        Boost.Python runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description    -n libboost_python-py3-%{lib_appendix}
This package contains the Boost.Python runtime libraries for python3
bindings.

%package     -n libboost_python-py3-%{lib_appendix}-devel
Summary:        Development headers for Boost.Python library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_python-py3-%{lib_appendix} = %{version}
Provides:       libboost_python3-devel = %{version}
Conflicts:      otherproviders(libboost_python3-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_python-py3-%{lib_appendix}-devel
Development headers for Boost.Python library. This package contains
library for python3 development for boost.

%if %{with python_numpy}
%package     -n libboost_numpy-py3-%{lib_appendix}
Summary:        Boost.Python.NumPy runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description    -n libboost_numpy-py3-%{lib_appendix}
This package contains the Boost.Python.NumPy runtime libraries for python3
bindings.

%package     -n libboost_numpy-py3-%{lib_appendix}-devel
Summary:        Development headers for Boost.Python.NumPy library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_numpy-py3-%{lib_appendix} = %{version}
Provides:       libboost_numpy3-devel = %{version}
Conflicts:      otherproviders(libboost_numpy3-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_numpy-py3-%{lib_appendix}-devel
Development headers for Boost.Python.NumPy library. This package contains
library for python3 development for boost.
%endif  # with numpy

%endif  # with python3

%package     -n libboost_serialization%{lib_appendix}
Summary:        Boost.Serialization runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_serialization%{lib_appendix}
This package contains the Boost.Serialization runtime library.

%package     -n libboost_serialization%{lib_appendix}-devel
Summary:        Development headers for Boost.Serialization library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_serialization%{lib_appendix} = %{version}
Provides:       libboost_serialization-devel = %{version}
Conflicts:      otherproviders(libboost_serialization-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_serialization%{lib_appendix}-devel
This package contains development headers for Boost.Serialization
library.

%package     -n libboost_signals%{lib_appendix}
Summary:        Boost.Signals runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_signals%{lib_appendix}
This package contains the Boost::Signals Runtime library.

%package     -n libboost_signals%{lib_appendix}-devel
Summary:        Development headers for Boost.Signals library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_signals%{lib_appendix} = %{version}
Provides:       libboost_signals-devel = %{version}
Conflicts:      otherproviders(libboost_signals-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_signals%{lib_appendix}-devel
This package contains development headers for Boost.Signals library.
Boost.Signals is deprecated in favour of Boost.Signals2, a header-only
library and part of libboost_headers-devel.

%package     -n libboost_stacktrace%{lib_appendix}
Summary:        Boost.Stacktrace runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_stacktrace%{lib_appendix}
This package contains the Boost.Stacktrace runtime library.

%package     -n libboost_stacktrace%{lib_appendix}-devel
Summary:        Development headers for Boost.Stacktrace library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_stacktrace%{lib_appendix} = %{version}
Provides:       libboost_stacktrace-devel = %{version}
Conflicts:      otherproviders(libboost_stacktrace-devel)

%description -n libboost_stacktrace%{lib_appendix}-devel
This package contains development headers for Boost.Stacktrace library.
Boost.Stacktrace is a simple C++03 library that provide information
about call sequence in a human-readable form.

%package     -n libboost_system%{lib_appendix}
Summary:        Boost.System runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_system%{lib_appendix}
This package contains the Boost.System runtime library.

%package     -n libboost_system%{lib_appendix}-devel
Summary:        Development headers for Boost.System library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_system%{lib_appendix} = %{version}
Provides:       libboost_system-devel = %{version}
Conflicts:      otherproviders(libboost_system-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_system%{lib_appendix}-devel
This package contains development headers for Boost.System library.

%package     -n libboost_thread%{lib_appendix}
Summary:        Boost.Thread runtime libraries
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_thread%{lib_appendix}
This package contains the Boost.Thread runtime library.

%package     -n libboost_thread%{lib_appendix}-devel
Summary:        Development headers for Boost.Thread library
Group:          Development/Libraries/C and C++
Requires:       libboost_chrono%{lib_appendix}-devel = %{version}
Requires:       libboost_date_time%{lib_appendix}-devel = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_thread%{lib_appendix} = %{version}
Provides:       libboost_thread-devel = %{version}
Conflicts:      otherproviders(libboost_thread-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_thread%{lib_appendix}-devel
This package contains development headers for Boost.Thread library.

%package     -n libboost_wave%{lib_appendix}
Summary:        Boost.Wave runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_wave%{lib_appendix}
This package contains the Boost::Wave runtime library.

%package     -n libboost_wave%{lib_appendix}-devel
Summary:        Development headers for Boost.Wave library
Group:          Development/Libraries/C and C++
Requires:       libboost_filesystem%{lib_appendix}-devel = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_serialization%{lib_appendix}-devel = %{version}
Requires:       libboost_wave%{lib_appendix} = %{version}
Provides:       libboost_wave-devel = %{version}
Conflicts:      otherproviders(libboost_wave-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_wave%{lib_appendix}-devel
This package contains development headers for Boost.Wave library.

%package     -n libboost_regex%{lib_appendix}
Summary:        Boost.Regex runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_regex%{lib_appendix}
This package contains the Boost.Regex runtime library.

%package     -n libboost_regex%{lib_appendix}-devel
Summary:        Development headers for Boost.Regex library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_regex%{lib_appendix} = %{version}
Provides:       libboost_regex-devel = %{version}
Conflicts:      otherproviders(libboost_regex-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_regex%{lib_appendix}-devel
This package contains development headers for Boost.Regex library.

%package     -n libboost_random%{lib_appendix}
Summary:        Boost.Random runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_random%{lib_appendix}
This package contains the Boost.Random runtime library.

%package     -n libboost_random%{lib_appendix}-devel
Summary:        Development headers for Boost.Random library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_random%{lib_appendix} = %{version}
Provides:       libboost_random-devel = %{version}
Conflicts:      otherproviders(libboost_random-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_random%{lib_appendix}-devel
This package contains Boost.Random development headers.

%package     -n libboost_chrono%{lib_appendix}
Summary:        The Boost::Chrono runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_chrono%{lib_appendix}
This package contains the Boost::Chrono runtime library.

%package     -n libboost_chrono%{lib_appendix}-devel
Summary:        Development headers for Boost.Chrono library
Group:          Development/Libraries/C and C++
Requires:       libboost_chrono%{lib_appendix} = %{version}
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Provides:       libboost_chrono-devel = %{version}
Conflicts:      otherproviders(libboost_chrono-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_chrono%{lib_appendix}-devel
This package contains Boost.Chrono development headers.

%package     -n libboost_locale%{lib_appendix}
Summary:        Boost::Locale runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_locale%{lib_appendix}
This package contains Boost::Locale runtime library.

%package     -n libboost_locale%{lib_appendix}-devel
Summary:        Development headers for Boost.Locale library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_locale%{lib_appendix} = %{version}
Provides:       libboost_locale-devel = %{version}
Conflicts:      otherproviders(libboost_locale-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_locale%{lib_appendix}-devel
This package contains development headers for Boost.Locale library.

%package     -n libboost_timer%{lib_appendix}
Summary:        Boost.Timer runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_timer%{lib_appendix}
This package contains Boost.Timer runtime library.

%package     -n libboost_timer%{lib_appendix}-devel
Summary:        Development headers for Boost.Timer library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_system%{lib_appendix}-devel = %{version}
Requires:       libboost_timer%{lib_appendix} = %{version}
Provides:       libboost_timer-devel = %{version}
Conflicts:      otherproviders(libboost_timer-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_timer%{lib_appendix}-devel
This package contains development headers for Boost.Timer library.

%package     -n libboost_type_erasure%{lib_appendix}
Summary:        Boost.TypeErasure runtime library
Group:          System/Libraries
Requires:       boost-license%{lib_appendix}

%description -n libboost_type_erasure%{lib_appendix}
This package contains Boost::TypeErasure runtime library.

%package     -n libboost_type_erasure%{lib_appendix}-devel
Summary:        Development headers for Boost.TypeErasure library
Group:          Development/Libraries/C and C++
PreReq:         libboost_headers%{lib_appendix}-devel = %{version}
Requires:       libboost_type_erasure%{lib_appendix} = %{version}
Provides:       libboost_type_erasure-devel = %{version}
Conflicts:      otherproviders(libboost_type_erasure-devel)
Conflicts:      boost-devel < 1.63

%description -n libboost_type_erasure%{lib_appendix}-devel
This package contains development headers for Boost.TypeErasure library.

%if %{with build_quickbook}
%package -n %{package_name}-quickbook
Summary:        Documentation tool geared towards C++
Group:          Development/Tools/Doc Generators
Requires:       boost-license%{lib_appendix}
Provides:       quickbook = %version
Conflicts:      otherproviders(quickbook)

%description -n %{package_name}-quickbook
QuickBook is a WikiWiki style documentation tool geared towards C++
documentation using simple rules and markup for simple formatting
tasks.
%endif

%prep
%setup -q -n boost_%{lib_appendix} -b 3
#everything in the tarball has the executable flag set ...
find -type f ! \( -name \*.sh -o -name \*.py -o -name \*.pl \) -exec chmod -x {} +
%patch1 -p1
%patch2
%patch3
%patch4
%patch5
%patch6 -p1
%patch7
%patch9 -p1
%patch10 -p1
%patch13
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1

%build
find . -type f -exec chmod u+w {} +

# General case
cat << EOF >user-config.jam
import os ;
local RPM_OPT_FLAGS = [ os.environ RPM_OPT_FLAGS ] ;
using gcc : : : <compileflags>\$(RPM_OPT_FLAGS) ;
project user-config ;
EOF

%if %build_base
cat << \EOF >.build
export LIBRARIES_FLAGS="--without-mpi --without-python"
%if ! %{with build_context}
# coroutine depends on context
LIBRARIES_FLAGS+=" --without-context --without-coroutine"
%endif

%if ! %{with boost_fiber}
LIBRARIES_FLAGS+=" --without-fiber"
%endif
EOF

%else # ! build_base

# Since boost build system is broken and incable of handling multiple python versions,
# we need to build boost piece by piece. First time to build all the non-python bits,
# then we build MPI and/or PYTHON modules for two python versions we need.
# MPI builds a python module.
cat << \EOF >.build
export PY_LIBRARIES_FLAGS="--with-python"
%if %{with build_mpi}
PY_LIBRARIES_FLAGS+=" --with-mpi"
%endif

# Dummy entry to make sure we don't build everything
export LIBRARIES_FLAGS="--with-system"

# Dummy entry replaced with real libraries, if we build something
%if %{with build_mpi}
LIBRARIES_FLAGS=" --with-graph_parallel"
%endif

EOF

%if %{with build_mpi}
# Set PATH, MANPATH and LD_LIBRARY_PATH for mpi
. %{_libdir}/mpi/gcc/%{mpi_implem}/bin/mpivars.sh
%endif

# Need specific Boost Jam config files.
#   1. one all "normal" libraries
#   2. one for each python version for for python/mpi libraries
#      use staging directories for MPI/PYTHON combinations.

# General case
cat << EOF >user-config.jam
alias boost_python_alias : : <library>/boost/python//boost_python ;
EOF
%endif # ! build_base

# bootstrap b2
./bootstrap.sh \
    --prefix=%{_prefix} --exec-prefix=%{_bindir} \
    --libdir=%{_libdir} --includedir=%{_includedir} \
    --with-toolset=gcc

# Read shared build instructions
. ./.build

%if ! %build_base

# Build boost base PYTHON and MPI, installed in python staging
cp user-config.jam user-config-py.jam
cat << EOF >> user-config-py.jam
using python 
     : %{py_ver}
     : %{_bindir}/python2
     : %{_includedir}/python%{py_ver}
     : %{_libdir}/python%{py_ver}
     :
     :
     ;
%if %{with build_mpi}
using mpi ;
%endif
EOF

%if %{with python2}
./b2 -d+2 -q --user-config=./user-config-py.jam \
    --build-type=minimal --build-dir=./python-build \
    --python-buildid=py2.7 \
    --stagedir=./python-stage %{?_smp_mflags} \
    $PY_LIBRARIES_FLAGS \
    threading=multi link=shared runtime-link=shared stage
%endif # with python2

# Build boost python3 and MPI, installed in python3 staging
%if %{with python3}
cp user-config.jam user-config-py3.jam
# sed -i -e 's#//boost_python#//boost_python3#' ./user-config-py3.jam
%{?!py3_abiflags: %define py3_abiflags m}
%{?!python3_version: %define python3_version %py3_ver }

cat << EOF >> user-config-py3.jam
using python
	: %{python3_version}
	: %{_bindir}/python3
	: %{_includedir}/python%{python3_version}%{py3_abiflags}
	:
	:
	: .%{py3_soflags}
	: %{py3_abiflags}
	;
%if %{with build_mpi}
using mpi ;
%endif
EOF

./b2 -d+2 -q --user-config=./user-config-py3.jam \
    --build-type=minimal --build-dir=./python3-build \
    --python-buildid=py3 \
    --stagedir=./python3-stage %{?_smp_mflags} \
    $PY_LIBRARIES_FLAGS \
    threading=multi link=shared runtime-link=shared stage
%endif # python3

%if %{with build_docs}
cat << EOF >>user-config.jam
using xsltproc ;

using boostbook
    : %{_datadir}/xml/docbook/stylesheet/nwalsh/current
    : %{_datadir}/xml/docbook/schema/dtd/4.2
    ;

using doxygen ;
EOF
%endif

# needed to get graph_parallel built
%if %{with build_mpi}
echo 'using mpi ;' >> ./user-config.jam
%endif

%endif # ! build_base

# This is run for both mini and non-mini build
./b2 -d+2 -q --user-config=./user-config.jam \
    --build-type=minimal --build-dir=./build \
    --stagedir=./stage %{?_smp_mflags} \
    $LIBRARIES_FLAGS \
    threading=multi link=shared runtime-link=shared stage

%if ! %build_base

# Verify that all symbols built in different stages are interchangeable.
# Can't be too careful!
cp %{SOURCE101} .
chmod +x symbol_diff.sh
%if %{with python3}
./symbol_diff.sh python3-stage/lib/libboost_mpi.so           stage/lib/libboost_mpi.so
./symbol_diff.sh python3-stage/lib/libboost_serialization.so stage/lib/libboost_serialization.so
%endif
%if %{with python2}
./symbol_diff.sh python-stage/lib/libboost_serialization.so  stage/lib/libboost_serialization.so
./symbol_diff.sh python-stage/lib/libboost_mpi.so            stage/lib/libboost_mpi.so
%endif
#./symbol_diff.sh python-stage/lib/libboost_serialization.so  stage/lib/libboost_serialization.so
#./symbol_diff.sh python-stage/lib/libboost_mpi.so            stage/lib/libboost_mpi.so

# Build documentation
%if %{with build_quickbook}
pushd tools/quickbook
../../b2 --user-config=../../user-config.jam --v2 dist-bin %{?_smp_mflags}
popd
%endif

%if %{with build_docs}
cd doc
./b2 --user-config=../user-config.jam --v2 man %{?_smp_mflags}
%endif

%endif # ! build_base

%install

# Read shared build instructions
. ./.build

%if ! %build_base

%if %{with build_mpi}
# Set PATH, MANPATH and LD_LIBRARY_PATH for mpi
. %{_libdir}/mpi/gcc/%{mpi_implem}/bin/mpivars.sh
%endif

%if %{with python3}
./b2 -d+2 -q --user-config=./user-config-py3.jam \
    --build-type=minimal --build-dir=./python3-build \
    --python-buildid=py3 \
    --prefix=%{buildroot}%{_prefix} --exec-prefix=%{buildroot}%{_bindir} \
    --libdir=%{buildroot}%{_libdir} --includedir=%{buildroot}%{_includedir} \
    --stagedir=./python3-stage %{?_smp_mflags} \
    $PY_LIBRARIES_FLAGS \
    threading=multi link=shared runtime-link=shared install
%endif

%if %{with python2}
./b2 -d+2 -q --user-config=./user-config-py.jam \
    --build-type=minimal --build-dir=./python-build \
    --python-buildid=py2.7 \
    --prefix=%{buildroot}%{_prefix} --exec-prefix=%{buildroot}%{_bindir} \
    --libdir=%{buildroot}%{_libdir} --includedir=%{buildroot}%{_includedir} \
    --stagedir=./python-stage %{?_smp_mflags} \
    $PY_LIBRARIES_FLAGS \
    threading=multi link=shared runtime-link=shared install
%endif

%endif # ! build_base

# Generic install
./b2 -d+2 -q \
     --build-type=minimal --build-dir=./build --stagedir=./stage \
     --prefix=%{buildroot}%{_prefix} --exec-prefix=%{buildroot}%{_bindir} \
     --libdir=%{buildroot}%{_libdir} --includedir=%{buildroot}%{_includedir} \
     --user-config=./user-config.jam \
     $LIBRARIES_FLAGS \
     threading=multi link=shared runtime-link=shared install

# No python dependencies in the main tree

! $(ldd %{buildroot}%{_libdir}/*.so* | grep python\\.)

%if ! %build_base
%if %{with python2}
ln -s libboost_mpi_python-py2_7.so %{buildroot}%{_libdir}/libboost_mpi_python.so
ln -s libboost_python-py2_7.so     %{buildroot}%{_libdir}/libboost_python.so
%endif

%if %{with python3}
! $(ldd %{buildroot}%{_libdir}/*.so* | grep python3-\\.)
ln -s libboost_python-py3.so       %{buildroot}%{_libdir}/libboost_python3.so
%endif

# Move Python libraries over to proper places
%if %{with python2}
mkdir -p %{buildroot}%{python2_sitearch}/boost/parallel/mpi/
mv %{buildroot}/%{_libdir}/mpi.so %{buildroot}%{python2_sitearch}/boost/parallel/mpi/
install -m 0644 libs/mpi/build/__init__.py %{buildroot}%{python2_sitearch}/boost/parallel/mpi/
install -m 0644 %{SOURCE11} %{buildroot}%{python2_sitearch}/boost/parallel
install -m 0644 %{SOURCE11} %{buildroot}%{python2_sitearch}/boost
%endif

%if %{with python3}
mkdir -p %{buildroot}%{python3_sitearch}/boost/parallel/mpi/
mv %{buildroot}/%{_libdir}/mpi.*so %{buildroot}%{python3_sitearch}/boost/parallel/mpi/mpi.%{py3_soflags}.so
install -m 0644 libs/mpi/build/__init__.py %{buildroot}%{python3_sitearch}/boost/parallel/mpi/
install -m 0644 %{SOURCE11} %{buildroot}%{python3_sitearch}/boost/parallel
install -m 0644 %{SOURCE11} %{buildroot}%{python3_sitearch}/boost
%endif

#install doc files
mkdir -p %{buildroot}%{my_docdir}
%if %{with boost_devel}
install -m 0644 %{SOURCE102} %{buildroot}%{my_docdir}
%endif
find libs/ -name \*.htm\* -o -name \*.css -o -name \*.js | xargs dos2unix
find . -name \*.htm\* -o -name \*.gif -o -name \*.css -o -name \*.jpg -o -name \*.png -o -name \*.ico | \
	tar --files-from=%{SOURCE4} -cf - --files-from=- | tar -C %{buildroot}%{my_docdir} -xf -
rm -rf %{buildroot}%{my_docdir}/boost
#ln -s %%{_includedir}/boost %%{buildroot}%%{my_docdir}
#ln -s ../LICENSE_1_0.txt %%{buildroot}%%{my_docdir}/libs
find %{buildroot}%{my_docdir} -name \*.py -exec chmod -x {} +
chmod -x ../boost_%{short_version}_pdf/*.pdf

%if %{with build_quickbook}
mkdir -p %{buildroot}%{_bindir}
install -m 0755 dist/bin/quickbook %{buildroot}%{_bindir}/quickbook
%endif

%endif # ! build_base

%if %build_base
mkdir -p %{buildroot}%{_bindir}
install -m 755 bjam %{buildroot}%{_bindir}
ln -s bjam %{buildroot}%{_bindir}/jam

# Remove exception library, but only if the symbols are not
# actually used. For now, the only symbol that is linked is
# should never be used as it's only available on Windows. So,
# verify that here.
objdump -Ctj .text -Ctj .text %{buildroot}%{_libdir}/libboost_exception.so | \
  grep '^[0-9a-f]\+[[:space:]]\+g[[:space:]]\+F' | \
  sed -e 's#[0-9a-f]\+[[:space:]]\+g[[:space:]]\+F[[:space:]]\+\.text[[:space:]]\+[0-9a-f]\+[[:space:]]\+##' | \
  diff %{SOURCE10} - || echo "WARNING: libexception symbol change?"
rm %{buildroot}%{_libdir}/libboost_exception.so
rm %{buildroot}%{_libdir}/libboost_exception.so.%{version}

%fdupes %{buildroot}%{_includedir}/boost
mkdir -p %{buildroot}%{my_docdir}
%else  # ! build_base
rm -r %{buildroot}%{_includedir}/boost
rm %{buildroot}%{_libdir}/libboost_serialization*
rmdir --ignore-fail-on-non-empty %{buildroot}%{_libdir}
%fdupes %{buildroot}%{my_docdir}
%endif

%if %build_base
%post -n libboost_atomic%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_container%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_context%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_coroutine%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_date_time%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_fiber%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_filesystem%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_iostreams%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_log%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_test%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_program_options%{lib_appendix} -p /sbin/ldconfig

%post -n libboost_regex%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_serialization%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_signals%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_thread%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_type_erasure%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_math%{lib_appendix} -p /sbin/ldconfig

%post -n libboost_graph%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_stacktrace%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_system%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_wave%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_random%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_chrono%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_locale%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_timer%{lib_appendix} -p /sbin/ldconfig

%else  # ! build_base

%if %{with python2}
%post -n libboost_python-py2_7-%{lib_appendix} -p /sbin/ldconfig
%if %{with python_numpy}
%post -n libboost_numpy-py2_7-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%if %{with python3}
%post -n libboost_python-py3-%{lib_appendix} -p /sbin/ldconfig
%if %{with python_numpy}
%post -n libboost_numpy-py3-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%if %{with build_mpi}
%post -n libboost_mpi%{lib_appendix} -p /sbin/ldconfig
%post -n libboost_graph_parallel%{lib_appendix} -p /sbin/ldconfig
%if %{with python2}
%post -n libboost_mpi_python-py2_7-%{lib_appendix} -p /sbin/ldconfig
%endif
%if %{with python3}
%post -n libboost_mpi_python-py3-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%endif # ! build_base

%if %build_base
%postun -n libboost_atomic%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_container%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_context%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_coroutine%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_date_time%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_fiber%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_filesystem%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_iostreams%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_log%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_test%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_program_options%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_regex%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_serialization%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_signals%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_thread%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_type_erasure%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_math%{lib_appendix} -p /sbin/ldconfig

%postun -n libboost_graph%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_stacktrace%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_system%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_wave%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_random%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_chrono%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_locale%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_timer%{lib_appendix} -p /sbin/ldconfig

%else # ! build_base

%if %{with python2}
%postun -n libboost_python-py2_7-%{lib_appendix} -p /sbin/ldconfig
%if %{with python_numpy}
%postun -n libboost_numpy-py2_7-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%if %{with python3}
%postun -n libboost_python-py3-%{lib_appendix} -p /sbin/ldconfig
%if %{with python_numpy}
%postun -n libboost_numpy-py3-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%if %{with build_mpi}
%postun -n libboost_mpi%{lib_appendix} -p /sbin/ldconfig
%postun -n libboost_graph_parallel%{lib_appendix} -p /sbin/ldconfig
%if %{with python2}
%postun -n libboost_mpi_python-py2_7-%{lib_appendix} -p /sbin/ldconfig
%endif
%if %{with python3}
%postun -n libboost_mpi_python-py3-%{lib_appendix} -p /sbin/ldconfig
%endif
%endif

%endif # build_base

%if %{build_base}
%files -n %{package_name}-jam
%defattr(-, root, root, -)
%{_bindir}/bjam
%{_bindir}/jam

%files -n libboost_atomic%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_atomic.so.%{version}

%files -n libboost_atomic%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_atomic.so

%files -n libboost_container%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_container.so.%{version}

%files -n libboost_container%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_container.so

%if %{with build_context}

%files -n libboost_context%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_context.so.%{version}

%files -n libboost_context%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_context.so

%files -n libboost_coroutine%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_coroutine.so.%{version}

%files -n libboost_coroutine%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_coroutine.so

%endif # if with build_context

%files -n libboost_date_time%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_date_time.so.%{version}

%files -n libboost_date_time%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_date_time.so

%if %{with boost_fiber}

%files -n libboost_fiber%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_fiber.so.%{version}

%files -n libboost_fiber%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_fiber.so

%endif # with boost_fiber

%files -n libboost_filesystem%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_filesystem.so.%{version}

%files -n libboost_filesystem%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_filesystem.so

%files -n libboost_graph%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_graph.so.%{version}

%files -n libboost_graph%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_graph.so

%files -n libboost_iostreams%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_iostreams.so.%{version}

%files -n libboost_iostreams%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_iostreams.so

%files -n libboost_log%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_log.so.%{version}
%{_libdir}/libboost_log_setup.so.%{version}

%files -n libboost_log%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_log.so
%{_libdir}/libboost_log_setup.so

%files -n libboost_math%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_math_c99f.so.%{version}
%{_libdir}/libboost_math_c99l.so.%{version}
%{_libdir}/libboost_math_c99.so.%{version}
%{_libdir}/libboost_math_tr1f.so.%{version}
%{_libdir}/libboost_math_tr1l.so.%{version}
%{_libdir}/libboost_math_tr1.so.%{version}

%files -n libboost_math%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_math_c99f.so
%{_libdir}/libboost_math_c99l.so
%{_libdir}/libboost_math_c99.so
%{_libdir}/libboost_math_tr1f.so
%{_libdir}/libboost_math_tr1l.so
%{_libdir}/libboost_math_tr1.so

%files -n libboost_test%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_prg_exec_monitor.so.%{version}
%{_libdir}/libboost_test_exec_monitor.so.%{version}
%{_libdir}/libboost_unit_test_framework.so.%{version}

%files -n libboost_test%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_prg_exec_monitor.so
%{_libdir}/libboost_test_exec_monitor.so
%{_libdir}/libboost_unit_test_framework.so

%files -n libboost_program_options%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_program_options.so.%{version}

%files -n libboost_program_options%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_program_options.so
%endif # build_base

%if ! %build_base

%if %{with build_mpi}
%files -n libboost_mpi%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_mpi.so.%{version}

%files -n libboost_mpi%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_mpi.so

%files -n libboost_graph_parallel%{lib_appendix}
%defattr(-,root,root)
%{_libdir}/libboost_graph_parallel.so.%{version}

%files -n libboost_graph_parallel%{lib_appendix}-devel
%defattr(-,root,root)
%{_libdir}/libboost_graph_parallel.so

%if %{with python2}
%files -n libboost_mpi_python-py2_7-%{lib_appendix}
%defattr(-,root,root)
%{_libdir}/libboost_mpi_python-py2_7.so.%{version}

%files -n libboost_mpi_python-py2_7-%{lib_appendix}-devel
%defattr(-,root,root)
%{_libdir}/libboost_mpi_python-py2_7.so
%{_libdir}/libboost_mpi_python.so

%files -n python2-boost_parallel_mpi%{lib_appendix}
%defattr(-, root, root, -)
%dir %{python2_sitearch}/boost
%dir %{python2_sitearch}/boost/parallel
%dir %{python2_sitearch}/boost/parallel/mpi
%{python2_sitearch}/boost/__init__.py
%{python2_sitearch}/boost/parallel/__init__.py
%{python2_sitearch}/boost/parallel/mpi/__init__.py
%{python2_sitearch}/boost/parallel/mpi/mpi.so
%endif # with python2

%if %{with python3}
%files -n libboost_mpi_python-py3-%{lib_appendix}
%defattr(-,root,root)
%{_libdir}/libboost_mpi_python-py3.so.%{version}

%files -n libboost_mpi_python-py3-%{lib_appendix}-devel
%defattr(-,root,root)
%{_libdir}/libboost_mpi_python-py3.so

%files -n python3-boost_parallel_mpi%{lib_appendix}
%defattr(-, root, root, -)
%dir %{python3_sitearch}/boost
%dir %{python3_sitearch}/boost/parallel
%dir %{python3_sitearch}/boost/parallel/mpi
%{python3_sitearch}/boost/__init__.py
%{python3_sitearch}/boost/parallel/__init__.py
%{python3_sitearch}/boost/parallel/mpi/__init__.py
%{python3_sitearch}/boost/parallel/mpi/mpi.%{py3_soflags}.so

%endif # with python3
%endif # with build_mpi

%if %{with python2}
%files -n libboost_python-py2_7-%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_python-py2_7.so.%{version}

%files -n libboost_python-py2_7-%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_python.so
%{_libdir}/libboost_python-py2_7.so

%if %{with python_numpy}
%files -n libboost_numpy-py2_7-%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_numpy-py2_7.so.%{version}

%files -n libboost_numpy-py2_7-%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_numpy-py2_7.so

%endif # with numpy
%endif # with python2

%if %{with python3}
%files -n libboost_python-py3-%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_python-py3.so.%{version}

%files -n libboost_python-py3-%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_python3.so
%{_libdir}/libboost_python-py3.so

%if %{with python_numpy}
%files -n libboost_numpy-py3-%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_numpy-py3.so.%{version}

%files -n libboost_numpy-py3-%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_numpy-py3.so

%endif  # with numpy
%endif  # with python3
%endif  # ! build_base

%if %build_base
%files -n libboost_serialization%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_serialization.so.%{version}
%{_libdir}/libboost_wserialization.so.%{version}

%files -n libboost_serialization%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_serialization.so
%{_libdir}/libboost_wserialization.so

%files -n libboost_signals%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_signals.so.%{version}

%files -n libboost_signals%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_signals.so

%files -n libboost_stacktrace%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_stacktrace_addr2line.so.%{version}
%{_libdir}/libboost_stacktrace_basic.so.%{version}
%{_libdir}/libboost_stacktrace_noop.so.%{version}

%files -n libboost_stacktrace%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_stacktrace_addr2line.so
%{_libdir}/libboost_stacktrace_basic.so
%{_libdir}/libboost_stacktrace_noop.so

%files -n libboost_system%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_system.so.%{version}

%files -n libboost_system%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_system.so

%files -n libboost_thread%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_thread.so.%{version}

%files -n libboost_thread%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_thread.so

%files -n libboost_wave%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_wave.so.%{version}

%files -n libboost_wave%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_wave.so

%files -n libboost_regex%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_regex.so.%{version}

%files -n libboost_regex%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_regex.so

%files -n libboost_random%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_random.so.%{version}

%files -n libboost_random%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_random.so

%files -n libboost_chrono%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_chrono.so.%{version}

%files -n libboost_chrono%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_chrono.so

%files -n libboost_locale%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_locale.so.%{version}

%files -n libboost_locale%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_locale.so

%files -n libboost_timer%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_timer.so.%{version}

%files -n libboost_timer%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_timer.so

%files -n libboost_type_erasure%{lib_appendix}
%defattr(-, root, root, -)
%{_libdir}/libboost_type_erasure.so.%{version}

%files -n libboost_type_erasure%{lib_appendix}-devel
%defattr(-, root, root, -)
%{_libdir}/libboost_type_erasure.so
%endif # if build_base

%if ! %build_base
%if %{with boost_devel}
%files -n %{package_name}-devel
%defattr(-, root, root, -)
%dir %{my_docdir}
%{my_docdir}/README.boost-devel
%endif

%files -n %{package_name}-doc-html
%defattr(-, root, root, -)
%dir %{my_docdir}
%doc %{my_docdir}/*
# %%exclude %%{my_docdir}/LICENSE_1_0.txt
%if %{with boost_devel}
%exclude %{my_docdir}/README.boost-devel
%endif

%if %{with build_docs}
%files doc-man
%defattr(-, root, root, -)
%doc %{_mandir}/man3/*.3.gz
%doc %{_mandir}/man7/*.7.gz
%doc %{_mandir}/man9/*.9.gz
%endif

%if %{with package_pdf}
%files -n %{package_name}-doc-pdf
%defattr(-, root, root, -)
%doc ../boost_%{short_version}_pdf/*.pdf
%endif

%if %{with build_quickbook}
%files -n %{package_name}-quickbook
%defattr(-, root, root, -)
%{_bindir}/quickbook
%endif
%endif # ! build_base

%if %build_base
%files -n libboost_headers%{lib_appendix}-devel
%defattr(-, root, root, -)
%dir %{_includedir}/boost
%{_includedir}/boost/*

%files -n boost-license%{lib_appendix}
%defattr(-, root, root, -)
%license LICENSE_1_0.txt

%endif

%changelog
